## 采购经理人指数

接口：cn_pmi

描述：采购经理人指数

限量：单次最大2000，一次可以提取全部数据

权限：用户积累2000积分可以使用，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| m | str | N | 月度（202401表示，2024年1月） |
| start_m | str | N | 开始月度 |
| end_m | str | N | 结束月度（e.g. fields='month,pmi010000,pmi010400'） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| month | str | N | 月份YYYYMM |
| pmi010000 | float | N | 制造业PMI |
| pmi010100 | float | N | 制造业PMI:企业规模/大型企业 |
| pmi010200 | float | N | 制造业PMI:企业规模/中型企业 |
| pmi010300 | float | N | 制造业PMI:企业规模/小型企业 |
| pmi010400 | float | N | 制造业PMI:构成指数/生产指数 |
| pmi010401 | float | N | 制造业PMI:构成指数/生产指数:企业规模/大型企业 |
| pmi010402 | float | N | 制造业PMI:构成指数/生产指数:企业规模/中型企业 |
| pmi010403 | float | N | 制造业PMI:构成指数/生产指数:企业规模/小型企业 |
| pmi010500 | float | N | 制造业PMI:构成指数/新订单指数 |
| pmi010501 | float | N | 制造业PMI:构成指数/新订单指数:企业规模/大型企业 |
| pmi010502 | float | N | 制造业PMI:构成指数/新订单指数:企业规模/中型企业 |
| pmi010503 | float | N | 制造业PMI:构成指数/新订单指数:企业规模/小型企业 |
| pmi010600 | float | N | 制造业PMI:构成指数/供应商配送时间指数 |
| pmi010601 | float | N | 制造业PMI:构成指数/供应商配送时间指数:企业规模/大型企业 |
| pmi010602 | float | N | 制造业PMI:构成指数/供应商配送时间指数:企业规模/中型企业 |
| pmi010603 | float | N | 制造业PMI:构成指数/供应商配送时间指数:企业规模/小型企业 |
| pmi010700 | float | N | 制造业PMI:构成指数/原材料库存指数 |
| pmi010701 | float | N | 制造业PMI:构成指数/原材料库存指数:企业规模/大型企业 |
| pmi010702 | float | N | 制造业PMI:构成指数/原材料库存指数:企业规模/中型企业 |
| pmi010703 | float | N | 制造业PMI:构成指数/原材料库存指数:企业规模/小型企业 |
| pmi010800 | float | N | 制造业PMI:构成指数/从业人员指数 |
| pmi010801 | float | N | 制造业PMI:构成指数/从业人员指数:企业规模/大型企业 |
| pmi010802 | float | N | 制造业PMI:构成指数/从业人员指数:企业规模/中型企业 |
| pmi010803 | float | N | 制造业PMI:构成指数/从业人员指数:企业规模/小型企业 |
| pmi010900 | float | N | 制造业PMI:其他/新出口订单 |
| pmi011000 | float | N | 制造业PMI:其他/进口 |
| pmi011100 | float | N | 制造业PMI:其他/采购量 |
| pmi011200 | float | N | 制造业PMI:其他/主要原材料购进价格 |
| pmi011300 | float | N | 制造业PMI:其他/出厂价格 |
| pmi011400 | float | N | 制造业PMI:其他/产成品库存 |
| pmi011500 | float | N | 制造业PMI:其他/在手订单 |
| pmi011600 | float | N | 制造业PMI:其他/生产经营活动预期 |
| pmi011700 | float | N | 制造业PMI:分行业/装备制造业 |
| pmi011800 | float | N | 制造业PMI:分行业/高技术制造业 |
| pmi011900 | float | N | 制造业PMI:分行业/基础原材料制造业 |
| pmi012000 | float | N | 制造业PMI:分行业/消费品制造业 |
| pmi020100 | float | N | 非制造业PMI:商务活动 |
| pmi020101 | float | N | 非制造业PMI:商务活动:分行业/建筑业 |
| pmi020102 | float | N | 非制造业PMI:商务活动:分行业/服务业业 |
| pmi020200 | float | N | 非制造业PMI:新订单指数 |
| pmi020201 | float | N | 非制造业PMI:新订单指数:分行业/建筑业 |
| pmi020202 | float | N | 非制造业PMI:新订单指数:分行业/服务业 |
| pmi020300 | float | N | 非制造业PMI:投入品价格指数 |
| pmi020301 | float | N | 非制造业PMI:投入品价格指数:分行业/建筑业 |
| pmi020302 | float | N | 非制造业PMI:投入品价格指数:分行业/服务业 |
| pmi020400 | float | N | 非制造业PMI:销售价格指数 |
| pmi020401 | float | N | 非制造业PMI:销售价格指数:分行业/建筑业 |
| pmi020402 | float | N | 非制造业PMI:销售价格指数:分行业/服务业 |
| pmi020500 | float | N | 非制造业PMI:从业人员指数 |
| pmi020501 | float | N | 非制造业PMI:从业人员指数:分行业/建筑业 |
| pmi020502 | float | N | 非制造业PMI:从业人员指数:分行业/服务业 |
| pmi020600 | float | N | 非制造业PMI:业务活动预期指数 |
| pmi020601 | float | N | 非制造业PMI:业务活动预期指数:分行业/建筑业 |
| pmi020602 | float | N | 非制造业PMI:业务活动预期指数:分行业/服务业 |
| pmi020700 | float | N | 非制造业PMI:新出口订单 |
| pmi020800 | float | N | 非制造业PMI:在手订单 |
| pmi020900 | float | N | 非制造业PMI:存货 |
| pmi021000 | float | N | 非制造业PMI:供应商配送时间 |
| pmi030000 | float | N | 中国综合PMI:产出指数 |

接口调用

```python
pro = ts.pro_api()

#获取指定字段
df = pro.cn_pmi(start_m='201901', end_m='202003', fields='month,pmi010000,pmi010400')
```

数据样例

```python
month pmi010000 pmi010100 pmi010200 pmi010300 pmi010400 pmi010401 pmi010402
0   202403     50.80     51.10     50.60     50.30     52.20     52.70     51.50
```